@@ -1,24 +1,8 @@
 /*
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 // ArchiveDialog -- archive/delete past events.
@@ -56,7 +40,7 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal, Akonadi::Inci
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Archive/Delete Past Events and To-dos"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
     mUser1Button = new QPushButton;
     buttonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
@@ -71,7 +55,7 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal, Akonadi::Inci
     mainLayout->addWidget(topFrame);
     mainLayout->addWidget(buttonBox);
 
-    QVBoxLayout *topLayout = new QVBoxLayout(topFrame);
+    auto *topLayout = new QVBoxLayout(topFrame);
     topLayout->setContentsMargins(0, 0, 0, 0);
     QLabel *descLabel = new QLabel(topFrame);
     descLabel->setText(
@@ -94,11 +78,11 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal, Akonadi::Inci
     topLayout->addWidget(descLabel);
     connect(descLabel, &QLabel::linkActivated, this, &ArchiveDialog::showWhatsThis);
 
-    QButtonGroup *radioBG = new QButtonGroup(this);
+    auto *radioBG = new QButtonGroup(this);
     connect(radioBG, QOverload<QAbstractButton *>::of(
                 &QButtonGroup::buttonClicked), this, &ArchiveDialog::slotActionChanged);
 
-    QHBoxLayout *dateLayout = new QHBoxLayout();
+    auto *dateLayout = new QHBoxLayout();
     dateLayout->setContentsMargins(0, 0, 0, 0);
     mArchiveOnceRB = new QRadioButton(i18nc("@option:radio",
                                             "Archive now items older than:"),
@@ -130,7 +114,7 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal, Akonadi::Inci
     // Checkbox, numinput and combo for auto-archiving (similar to kmail's
     // mExpireFolderCheckBox/mReadExpiryTimeNumInput in kmfolderdia.cpp)
     QWidget *autoArchiveHBox = new QWidget(topFrame);
-    QHBoxLayout *autoArchiveHBoxHBoxLayout = new QHBoxLayout(autoArchiveHBox);
+    auto *autoArchiveHBoxHBoxLayout = new QHBoxLayout(autoArchiveHBox);
     autoArchiveHBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addWidget(autoArchiveHBox);
     mAutoArchiveRB = new QRadioButton(i18nc("@option:radio",
@@ -179,7 +163,7 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal, Akonadi::Inci
         i18nc("@item:inlistbox expiration in monthly units", "Month(s)"));
     mExpiryUnitsComboBox->setEnabled(false);
 
-    QHBoxLayout *fileLayout = new QHBoxLayout();
+    auto *fileLayout = new QHBoxLayout();
     fileLayout->setContentsMargins(0, 0, 0, 0);
     QLabel *l = new QLabel(i18nc("@label", "Archive &file:"), topFrame);
     fileLayout->addWidget(l);
