@@ -1,23 +1,7 @@
 /*
-  Copyright (C) 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 // NOTE: The code of the following methods is taken from
@@ -29,7 +13,6 @@
 #include "utils.h"
 
 #include <KCalendarCore/Incidence>
-#include <Akonadi/Calendar/ETMCalendar>
 #include <Akonadi/Calendar/IncidenceChanger>
 
 #include <KLocalizedString>
@@ -44,11 +27,10 @@ using namespace KCalendarCore;
 struct MultiChange {
     Akonadi::Item parent;
     QVector<Akonadi::Item::Id> children;
-    bool success;
+    bool success = true;
 
     explicit MultiChange(const Akonadi::Item &parent = Akonadi::Item())
         : parent(parent)
-        , success(true)
     {
     }
 
