@@ -1,30 +1,17 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "testfreebusyitemmodel.h"
-#include "modeltest.h"
 #include "../freebusyitemmodel.h"
 #include "../freebusyitem.h"
 
 #include <KCalendarCore/Attendee>
 
+#include <QAbstractItemModelTester>
 #include <QTest>
 
 using namespace CalendarSupport;
@@ -35,14 +22,14 @@ QTEST_GUILESS_MAIN(FreeBusyItemModelTest)
 
 void FreeBusyItemModelTest::testModelValidity()
 {
-    FreeBusyItemModel *model = new FreeBusyItemModel(this);
-    new ModelTest(model, this);
+    auto *model = new FreeBusyItemModel(this);
+    new QAbstractItemModelTester(model, this);
 
     QVERIFY(model->rowCount() == 0);
 
     const QDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), Qt::UTC);
     const QDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), Qt::UTC);
-    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
+    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral("fred@example.com"));
     KCalendarCore::FreeBusy::Ptr fb1(new KCalendarCore::FreeBusy());
 
     fb1->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
@@ -88,17 +75,17 @@ void FreeBusyItemModelTest::testModelValidity()
 
 void FreeBusyItemModelTest::testModelValidity2()
 {
-    FreeBusyItemModel *model = new FreeBusyItemModel(this);
-    new ModelTest(model, this);
+    auto *model = new FreeBusyItemModel(this);
+    new QAbstractItemModelTester(model, this);
 
     const QDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), Qt::UTC);
     const QDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), Qt::UTC);
     const QDateTime dt3(QDate(2010, 7, 24), QTime(12, 0, 0), Qt::UTC);
     const QDateTime dt4(QDate(2010, 7, 24), QTime(14, 0, 0), Qt::UTC);
 
-    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
-    KCalendarCore::Attendee a2(QStringLiteral("joe"), QStringLiteral( "joe@example.com"));
-    KCalendarCore::Attendee a3(QStringLiteral("max"), QStringLiteral( "max@example.com"));
+    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral("fred@example.com"));
+    KCalendarCore::Attendee a2(QStringLiteral("joe"), QStringLiteral("joe@example.com"));
+    KCalendarCore::Attendee a3(QStringLiteral("max"), QStringLiteral("max@example.com"));
     KCalendarCore::FreeBusy::Ptr fb1(new KCalendarCore::FreeBusy());
     KCalendarCore::FreeBusy::Ptr fb2(new KCalendarCore::FreeBusy());
     KCalendarCore::FreeBusy::Ptr fb3(new KCalendarCore::FreeBusy());
@@ -211,12 +198,12 @@ void FreeBusyItemModelTest::testModelValidity2()
 
 void FreeBusyItemModelTest::testInsertFreeBusy()
 {
-    FreeBusyItemModel *model = new FreeBusyItemModel(this);
-    new ModelTest(model, this);
+    auto *model = new FreeBusyItemModel(this);
+    new QAbstractItemModelTester(model, this);
 
     const QDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), Qt::UTC);
     const QDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), Qt::UTC);
-    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral( "fred@example.com"));
+    KCalendarCore::Attendee a1(QStringLiteral("fred"), QStringLiteral("fred@example.com"));
     KCalendarCore::FreeBusy::Ptr fb1(new KCalendarCore::FreeBusy());
     fb1->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
     fb1->addPeriod(dt2, KCalendarCore::Duration(60 * 60));
