@@ -1,29 +1,16 @@
 /*
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-    Author: Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileContributor: Tobias Koenig <tokoe@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidenceviewer.h"
 #include "incidenceviewer_p.h"
 #include "attachmenthandler.h"
 #include "utils.h"
+#include "urihandler.h"
 
-#include "KdepimDBusInterfaces/UriHandler"
 #include "incidenceattachmentmodel.h"
 
 #include <CollectionFetchJob>
@@ -69,11 +56,7 @@ class Q_DECL_HIDDEN IncidenceViewer::Private
 {
 public:
     Private(IncidenceViewer *parent)
-        : mCalendar(nullptr)
-        , mParent(parent)
-        , mParentCollectionFetchJob(nullptr)
-        , mAttachmentModel(nullptr)
-        , mDelayedClear(false)
+        : mParent(parent)
     {
         mAttachmentHandler = new AttachmentHandler(parent);
         mBrowser = new TextBrowser;
@@ -106,7 +89,7 @@ public:
         mParentCollection = Akonadi::Collection();
 
         if (!job->error()) {
-            Akonadi::CollectionFetchJob *fetchJob
+            auto *fetchJob
                 = qobject_cast<Akonadi::CollectionFetchJob *>(job);
             if (!fetchJob->collections().isEmpty()) {
                 mParentCollection = fetchJob->collections().at(0);
@@ -124,7 +107,7 @@ public:
     }
 
     Akonadi::ETMCalendar *mCalendar = nullptr;
-    IncidenceViewer *mParent = nullptr;
+    IncidenceViewer *const mParent;
     TextBrowser *mBrowser = nullptr;
     Akonadi::Item mCurrentItem;
     QString mHeaderText;
@@ -155,7 +138,7 @@ IncidenceViewer::IncidenceViewer(QWidget *parent)
 
 void IncidenceViewer::init()
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     d->mBrowser->setOpenLinks(true);
