@@ -1,27 +1,12 @@
 /*
-  Copyright (c) 1998 Preston Brown <pbrown@kde.org>
-  Copyright (C) 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2008 Ron Goodheart <rong.dev@gmail.com>
-  Copyright (c) 2012-2013 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 1998 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2008 Ron Goodheart <rong.dev@gmail.com>
+  SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
+
 #ifndef CALENDARSUPPORT_PRINTING_CALPRINTPLUGINBASE_H
 #define CALENDARSUPPORT_PRINTING_CALPRINTPLUGINBASE_H
 
@@ -30,11 +15,11 @@
 
 #include <Akonadi/Calendar/ETMCalendar>
 
-#include <KCalCore/Event>
-#include <KCalCore/Journal>
-#include <KCalCore/Todo>
-#include <KDateTime>
+#include <KCalendarCore/Event>
+#include <KCalendarCore/Journal>
+#include <KCalendarCore/Todo>
 
+#include <QDateTime>
 #include <QPainter>
 
 class PrintCellItem;
@@ -52,9 +37,7 @@ class QWidget;
 
 #define TIMELINE_WIDTH 50           // width of timeline (day and timetable)
 
-namespace CalendarSupport
-{
-
+namespace CalendarSupport {
 /**
   Base class for Calendar printing classes. Each sub class represents one
   calendar print format.
@@ -72,12 +55,12 @@ public:
       Constructor
     */
     CalPrintPluginBase();
-    virtual ~CalPrintPluginBase();
+    ~CalPrintPluginBase() override;
 
     /**
       Returns widget for configuring the print format.
     */
-    QWidget *createConfigWidget(QWidget *) Q_DECL_OVERRIDE;
+    QWidget *createConfigWidget(QWidget *) override;
 
     /**
       Actually do the printing.
@@ -90,7 +73,7 @@ public:
     /**
       Start printing.
     */
-    void doPrint(QPrinter *printer) Q_DECL_OVERRIDE;
+    void doPrint(QPrinter *printer) override;
 
     /**
       Load print format configuration from config file.
@@ -104,11 +87,11 @@ public:
     /**
       Load complete config. This also calls loadConfig() of the derived class.
     */
-    void doLoadConfig() Q_DECL_OVERRIDE;
+    void doLoadConfig() override;
     /**
       Save complete config. This also calls saveConfig() of the derived class.
     */
-    void doSaveConfig() Q_DECL_OVERRIDE;
+    void doSaveConfig() override;
 
     /** HELPER FUNCTIONS */
 public:
@@ -125,7 +108,7 @@ public:
     */
     static int weekdayColumn(int weekday);
 
-    QPrinter::Orientation orientation() const;
+    QPageLayout::Orientation orientation() const;
 
     /** Returns the height of the page header. If the height was explicitly
         set using setHeaderHeight, that value is returned, otherwise a
@@ -192,8 +175,7 @@ public:
       @param str The string to print inside the box
       @param flags is a bitwise OR of Qt::AlignmentFlags and Qt::TextFlags values.
     */
-    void showEventBox(QPainter &p, int linewidth, const QRect &box,
-                      const KCalCore::Incidence::Ptr &incidence, const QString &str, int flags = -1);
+    void showEventBox(QPainter &p, int linewidth, const QRect &box, const KCalendarCore::Incidence::Ptr &incidence, const QString &str, int flags = -1);
 
     /**
       Draw a subheader box with a shaded background and the given string
@@ -211,8 +193,7 @@ public:
       @param str ext to be printed inside the box
       @param flags is a bitwise OR of Qt::AlignmentFlags and Qt::TextFlags values.
     */
-    void drawVerticalBox(QPainter &p, int linewidth, const QRect &box, const QString &str,
-                         int flags = -1);
+    void drawVerticalBox(QPainter &p, int linewidth, const QRect &box, const QString &str, int flags = -1);
 
     /**
       Draw a component box with a heading (printed in bold).
@@ -235,10 +216,7 @@ public:
               the contents, use the return value as the top-value of your
               custom contents in that case.
     */
-    int drawBoxWithCaption(QPainter &p, const QRect &box, const QString &caption,
-                           const QString &contents, bool sameLine, bool expand,
-                           const QFont &captionFont, const QFont &textFont,
-                           bool richContents = false);
+    int drawBoxWithCaption(QPainter &p, const QRect &box, const QString &caption, const QString &contents, bool sameLine, bool expand, const QFont &captionFont, const QFont &textFont, bool richContents = false);
 
     /**
       Draw the gray header bar of the printout to the QPainter.
@@ -268,10 +246,7 @@ public:
               is box.bottom, otherwise it is larger than box.bottom
               and matches the y-coordinate of the surrounding rectangle.
     */
-    int drawHeader(QPainter &p, const QString &title,
-                   const QDate &month1, const QDate &month2,
-                   const QRect &box, bool expand = false,
-                   QColor backColor = QColor());
+    int drawHeader(QPainter &p, const QString &title, const QDate &month1, const QDate &month2, const QRect &box, bool expand = false, QColor backColor = QColor());
 
     /**
       Draw a page footer containing the printing date and possibly
@@ -300,9 +275,7 @@ public:
       @param toDate Last date of the printed dates
       @param box coordinates of the box for the days of the week
     */
-    void drawDaysOfWeek(QPainter &p,
-                        const QDate &fromDate, const QDate &toDate,
-                        const QRect &box);
+    void drawDaysOfWeek(QPainter &p, const QDate &fromDate, const QDate &toDate, const QRect &box);
     /**
       Draw a single weekday name in a box inside the given area of the painter.
       This is called in a loop by drawDaysOfWeek.
@@ -322,9 +295,7 @@ public:
       @param toTime End time of the time range to display
       @param box coordinates of the timeline
     */
-    void drawTimeLine(QPainter &p,
-                      const QTime &fromTime, const QTime &toTime,
-                      const QRect &box);
+    void drawTimeLine(QPainter &p, const QTime &fromTime, const QTime &toTime, const QRect &box);
 
     /**
       Draw the all-day box for the agenda print view (the box on top which
@@ -346,10 +317,7 @@ public:
       @param excludePrivate Whether to exclude Incidence marked private.
       @return The height used for the all-day box.
     */
-    int drawAllDayBox(QPainter &p, const KCalCore::Event::List &eventList,
-                      const QDate &qd, bool expandable,
-                      const QRect &box,
-                      bool excludeConfidential, bool excludePrivate);
+    int drawAllDayBox(QPainter &p, const KCalendarCore::Event::List &eventList, const QDate &qd, bool expandable, const QRect &box, bool excludeConfidential, bool excludePrivate);
     /**
       Draw the agenda box for the day print style (the box showing all events of that day).
       Also draws a grid with half-hour spacing of the grid lines.
@@ -376,19 +344,9 @@ public:
       @param excludePrivate Whether to exclude Incidence marked private.
       @param workDays List of workDays
     */
-    void drawAgendaDayBox(QPainter &p, const KCalCore::Event::List &eventList,
-                          const QDate &qd, bool expandable,
-                          const QTime &fromTime, const QTime &toTime,
-                          const QRect &box,
-                          bool includeDescription, bool excludeTime,
-                          bool excludeConfidential, bool excludePrivate,
-                          const QList<QDate> &workDays);
+    void drawAgendaDayBox(QPainter &p, const KCalendarCore::Event::List &eventList, const QDate &qd, bool expandable, const QTime &fromTime, const QTime &toTime, const QRect &box, bool includeDescription, bool excludeTime, bool excludeConfidential, bool excludePrivate, const QList<QDate> &workDays);
 
-    void drawAgendaItem(PrintCellItem *item, QPainter &p,
-                        const KDateTime &startPrintDate,
-                        const KDateTime &endPrintDate,
-                        float minlen, const QRect &box,
-                        bool includeDescription, bool excludeTime);
+    void drawAgendaItem(PrintCellItem *item, QPainter &p, const QDateTime &startPrintDate, const QDateTime &endPrintDate, float minlen, const QRect &box, bool includeDescription, bool excludeTime);
 
     /**
       Draw the box containing a list of all events of the given day (with their times,
@@ -409,16 +367,8 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawDayBox(QPainter &p, const QDate &qd,
-                    const QTime &fromTime, const QTime &toTime,
-                    const QRect &box,
-                    bool fullDate = false, bool printRecurDaily = true,
-                    bool printRecurWeekly = true,
-                    bool singleLineLimit = true,
-                    bool showNoteLines = false,
-                    bool includeDescription = false,
-                    bool excludeDescription = true,
-                    bool excludePrivate = true);
+    void drawDayBox(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime, const QRect &box, bool fullDate = false, bool printRecurDaily = true, bool printRecurWeekly = true, bool singleLineLimit = true, bool showNoteLines = false, bool includeDescription = false,
+                    bool excludeDescription = true, bool excludePrivate = true);
     /**
       Draw the week (filofax) table of the week containing the date qd. The first
       three days of the week will be shown in the first column (using drawDayBox),
@@ -435,11 +385,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawWeek(QPainter &p, const QDate &qd,
-                  const QTime &fromTime, const QTime &toTime,
-                  const QRect &box, bool singleLineLimit,
-                  bool showNoteLines, bool includeDescription,
-                  bool excludeConfidential, bool excludePrivate);
+    void drawWeek(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime, const QRect &box, bool singleLineLimit, bool showNoteLines, bool includeDescription, bool excludeConfidential, bool excludePrivate);
     /**
       Draw the (filofax) table for a bunch of days, using drawDayBox.
       @param p QPainter of the printout
@@ -454,11 +400,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawDays(QPainter &p, const QDate &start, const QDate &end,
-                  const QTime &fromTime, const QTime &toTime,
-                  const QRect &box, bool singleLineLimit, bool showNoteLines,
-                  bool includeDescription, bool excludeConfidential,
-                  bool excludePrivate);
+    void drawDays(QPainter &p, const QDate &start, const QDate &end, const QTime &fromTime, const QTime &toTime, const QRect &box, bool singleLineLimit, bool showNoteLines, bool includeDescription, bool excludeConfidential, bool excludePrivate);
     /**
       Draw the timetable view of the given time range from fromDate to toDate.
       On the left side the time scale is printed (using drawTimeLine), then each
@@ -479,11 +421,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawTimeTable(QPainter &p, const QDate &fromDate, const QDate &toDate,
-                       bool expandable, const QTime &fromTime, const QTime &toTime,
-                       const QRect &box, bool includeDescription,
-                       bool excludeTime, bool excludeConfidential,
-                       bool excludePrivate);
+    void drawTimeTable(QPainter &p, const QDate &fromDate, const QDate &toDate, bool expandable, const QTime &fromTime, const QTime &toTime, const QRect &box, bool includeDescription, bool excludeTime, bool excludeConfidential, bool excludePrivate);
 
     /**
       Draw the month table of the month containing the date qd. Each day gets one
@@ -505,13 +443,7 @@ public:
       @param excludePrivate Whether to exclude Incidence marked private.
       @param box coordinates of the month.
     */
-    void drawMonthTable(QPainter &p, const QDate &qd,
-                        const QTime &fromTime, const QTime &toTime,
-                        bool weeknumbers,
-                        bool recurDaily, bool recurWeekly, bool singleLineLimit,
-                        bool showNoteLines, bool includeDescription,
-                        bool excludeConfidential, bool excludePrivate,
-                        const QRect &box);
+    void drawMonthTable(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime, bool weeknumbers, bool recurDaily, bool recurWeekly, bool singleLineLimit, bool showNoteLines, bool includeDescription, bool excludeConfidential, bool excludePrivate, const QRect &box);
     /**
       Draw a vertical representation of the month containing the date dt. Each
       day gets one line.
@@ -529,10 +461,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawMonth(QPainter &p, const QDate &dt, const QRect &box,
-                   int maxdays = -1, int subDailyFlags = TimeBoxes,
-                   int holidaysFlags = Text,
-                   bool excludeConfidential = false, bool excludePrivate = false);
+    void drawMonth(QPainter &p, const QDate &dt, const QRect &box, int maxdays = -1, int subDailyFlags = TimeBoxes, int holidaysFlags = Text, bool excludeConfidential = false, bool excludePrivate = false);
 
     /**
       Internal class representing the start of a todo.
@@ -575,15 +504,8 @@ public:
       @param r Internal (used when printing sub-to-dos to give information
       about its parent)
     */
-    void drawTodo(int &count, const KCalCore::Todo::Ptr &todo, QPainter &p,
-                  KCalCore::TodoSortField sortField,
-                  KCalCore::SortDirection sortDir,
-                  bool connectSubTodos, bool strikeoutCompleted, bool desc,
-                  int posPriority, int posSummary, int posDueDt,
-                  int posPercentComplete, int level, int x, int &y,
-                  int width, int pageHeight,
-                  const KCalCore::Todo::List &todoList, TodoParentStart *r,
-                  bool excludeConfidential, bool excludePrivate);
+    void drawTodo(int &count, const KCalendarCore::Todo::Ptr &todo, QPainter &p, KCalendarCore::TodoSortField sortField, KCalendarCore::SortDirection sortDir, bool connectSubTodos, bool strikeoutCompleted, bool desc, int posPriority, int posSummary, int posDueDt, int posPercentComplete, int level,
+                  int x, int &y, int width, int pageHeight, const KCalendarCore::Todo::List &todoList, TodoParentStart *r, bool excludeConfidential, bool excludePrivate);
 
     /**
       Draws single journal item.
@@ -595,8 +517,7 @@ public:
       @param pageHeight Total height allowed for the list on a page. If an item
                    would be below that line, a new page is started.
     */
-    void drawJournal(const KCalCore::Journal::Ptr &journal, QPainter &p, int x, int &y,
-                     int width, int pageHeight);
+    void drawJournal(const KCalendarCore::Journal::Ptr &journal, QPainter &p, int x, int &y, int width, int pageHeight);
     /**
       Draws text lines splitting on page boundaries.
       @param p QPainter of the printout
@@ -606,12 +527,9 @@ public:
       @param pageHeight size of the page. A new page is started when the
              text reaches the end of the page.
     */
-    void drawTextLines(QPainter &p, const QString &entry,
-                       int x, int &y, int width, int pageHeight,
-                       bool richTextEntry);
+    void drawTextLines(QPainter &p, const QString &entry, int x, int &y, int width, int pageHeight, bool richTextEntry);
 
-    void drawSplitHeaderRight(QPainter &p, const QDate &fd, const QDate &td,
-                              const QDate &cd, int width, int height);
+    void drawSplitHeaderRight(QPainter &p, const QDate &fd, const QDate &td, const QDate &cd, int width, int height);
 
     /**
       Draws dotted lines for notes in a box.
@@ -623,17 +541,11 @@ public:
 
 protected:
     QTime dayStart() const;
-    QColor categoryBgColor(const KCalCore::Incidence::Ptr &incidence) const;
+    QColor categoryBgColor(const KCalendarCore::Incidence::Ptr &incidence) const;
 
-    void drawIncidence(QPainter &p, const QRect &dayBox, const QString &time,
-                       const QString &summary, const QString &description,
-                       int &textY, bool singleLineLimit,
-                       bool includeDescription, bool richDescription);
+    void drawIncidence(QPainter &p, const QRect &dayBox, const QString &time, const QString &summary, const QString &description, int &textY, bool singleLineLimit, bool includeDescription, bool richDescription);
     QString toPlainText(const QString &htmlText);
-    void drawTodoLines(QPainter &p, const QString &entry,
-                       int x, int &y, int width, int pageHeight,
-                       bool richTextEntry, QList<TodoParentStart *> &startPoints,
-                       bool connectSubTodos);
+    void drawTodoLines(QPainter &p, const QString &entry, int x, int &y, int width, int pageHeight, bool richTextEntry, QList<TodoParentStart *> &startPoints, bool connectSubTodos);
 
 protected:
     bool mUseColors;
@@ -652,19 +564,17 @@ private:
     /**
      * Sets the QPainter's brush and pen color according to the Incidence's category.
      */
-    void setColorsByIncidenceCategory(QPainter &p,
-                                      const KCalCore::Incidence::Ptr &incidence) const;
+    void setColorsByIncidenceCategory(QPainter &p, const KCalendarCore::Incidence::Ptr &incidence) const;
 
     QString holidayString(const QDate &date) const;
 
-    KCalCore::Event::Ptr holidayEvent(const QDate &date) const;
+    KCalendarCore::Event::Ptr holidayEvent(const QDate &date) const;
 
     /**
      * Returns a nice QColor for text, give the input color &c.
      */
     QColor getTextColor(const QColor &c) const;
 };
-
 }
 
 #endif
